v1alpha1

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 4, 2025 License: LGPL-3.0 Imports: 12 Imported by: 0

Documentation

Overview

Copyright 2024.

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Package v1alpha1 contains API Schema definitions for the butane v1alpha1 API group +kubebuilder:object:generate=true +groupName=butane.operators.naval-group.com

Index

Constants

This section is empty.

Variables

var (
	// GroupVersion is group version used to register these objects
	GroupVersion = schema.GroupVersion{Group: "butane.operators.naval-group.com", Version: "v1alpha1"}

	// SchemeBuilder is used to add go types to the GroupVersionKind scheme
	SchemeBuilder = &scheme.Builder{GroupVersion: GroupVersion}

	// AddToScheme adds the types in this group-version to the given scheme.
	AddToScheme = SchemeBuilder.AddToScheme
)

Functions

This section is empty.

Types

type ButaneConfig

type ButaneConfig struct {
	metav1.TypeMeta   `json:",inline"`
	metav1.ObjectMeta `json:"metadata,omitempty"`

	Spec   ButaneConfigSpec   `json:"spec,omitempty"`
	Status ButaneConfigStatus `json:"status,omitempty"`
}

ButaneConfig is a resource that transplane Butane config into an Ignition formatted secret.

func (*ButaneConfig) DeepCopy

func (in *ButaneConfig) DeepCopy() *ButaneConfig

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ButaneConfig.

func (*ButaneConfig) DeepCopyInto

func (in *ButaneConfig) DeepCopyInto(out *ButaneConfig)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*ButaneConfig) DeepCopyObject

func (in *ButaneConfig) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

func (*ButaneConfig) Default

func (r *ButaneConfig) Default(ctx context.Context) error

Default implements webhook.Defaulter

func (*ButaneConfig) SetupWebhookWithManager

func (r *ButaneConfig) SetupWebhookWithManager(mgr ctrl.Manager) error

SetupWebhookWithManager will setup the manager to manage the webhooks

func (*ButaneConfig) ValidateCreate

func (r *ButaneConfig) ValidateCreate(ctx context.Context) (admission.Warnings, error)

ValidateCreate implements validation logic for ButaneConfig creation

func (*ButaneConfig) ValidateDelete

func (r *ButaneConfig) ValidateDelete(ctx context.Context) (admission.Warnings, error)

ValidateDelete implements validation logic for ButaneConfig deletion

func (*ButaneConfig) ValidateUpdate

func (r *ButaneConfig) ValidateUpdate(ctx context.Context, old runtime.Object) (admission.Warnings, error)

ValidateUpdate implements validation logic for ButaneConfig updates

type ButaneConfigList

type ButaneConfigList struct {
	metav1.TypeMeta `json:",inline"`
	metav1.ListMeta `json:"metadata,omitempty"`
	Items           []ButaneConfig `json:"items"`
}

ButaneConfigList contains a list of ButaneConfig

func (*ButaneConfigList) DeepCopy

func (in *ButaneConfigList) DeepCopy() *ButaneConfigList

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ButaneConfigList.

func (*ButaneConfigList) DeepCopyInto

func (in *ButaneConfigList) DeepCopyInto(out *ButaneConfigList)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*ButaneConfigList) DeepCopyObject

func (in *ButaneConfigList) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type ButaneConfigSpec

type ButaneConfigSpec struct {
	// An object that follows Butane specifications.
	// More info: https://coreos.github.io/butane/specs/
	Config runtime.RawExtension `json:"config,omitempty"`
}

ButaneConfigSpec defines the desired state of ButaneConfig

func (*ButaneConfigSpec) DeepCopy

func (in *ButaneConfigSpec) DeepCopy() *ButaneConfigSpec

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ButaneConfigSpec.

func (*ButaneConfigSpec) DeepCopyInto

func (in *ButaneConfigSpec) DeepCopyInto(out *ButaneConfigSpec)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ButaneConfigStatus

type ButaneConfigStatus struct {
	// The name of the generated secret containing the ignition content in userdata key
	// More info: https://coreos.github.io/ignition/specs/
	SecretName string `json:"secretName,omitempty"`
}

ButaneConfigStatus defines the observed state of ButaneConfig

func (*ButaneConfigStatus) DeepCopy

func (in *ButaneConfigStatus) DeepCopy() *ButaneConfigStatus

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ButaneConfigStatus.

func (*ButaneConfigStatus) DeepCopyInto

func (in *ButaneConfigStatus) DeepCopyInto(out *ButaneConfigStatus)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

Jump to